@@ -34,10 +34,7 @@ import tornado.options
 # Global resource handler variable
 resource_manager = ResourceManager()
 
-pkg_root = Path(__file__).absolute()
-if __name__ == '__main__':
-    # If we're running this file directly, then we have to go up one more
-    pkg_root = pkg_root.parent
+pkg_root = Path(__file__).absolute().parent
 assets_path = pkg_root / 'assets'
 data_path = Path.cwd() / 'local_hs_resources'
 
